@@ -1,8 +1,8 @@
-import os
 import random
 import socket
 import threading
 
+from is3_python_sdk.config.load_config import load_local_config
 from is3_python_sdk.data_query import iS3PythonApi
 
 sequenceNum = 0
@@ -10,14 +10,22 @@ instanceId = random.randint(0, 2 ** 63 - 1)
 hostname = socket.gethostname()
 ip = socket.gethostbyname(hostname)
 
+config = load_local_config()
+xAccessKey = config['key']['X-Access-Key']
+xSecretKey = config['key']['X-Secret-Key']
+headers = {
+    'Content-Type': 'application/json',
+    'X-Access-Key': xAccessKey,
+    'X-Secret-Key': xSecretKey
+}
+iS3Addr = config['domain']['addr']
+
 
 def time_task():
     global sequenceNum
     global instanceId
     global ip
     print("发送心跳")
-    project_root = os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))
-    filePath = os.path.join(project_root, 'config/config.ini')
     threading.Timer(10, time_task).start()
     requestId = random.randint(0, 2 ** 63 - 1)
     jsonData = {
@@ -26,7 +34,7 @@ def time_task():
         "sequenceNum": sequenceNum,
         "ip": ip,
     }
-    is3Api = iS3PythonApi(filePath, None)
+    is3Api = iS3PythonApi(headers, iS3Addr, None)
     response = is3Api.sendHeartbeat(jsonData)
     if response.get('code') == 500:
         sequenceNum = 0
