@@ -1,13 +1,18 @@
 import json
 
 from is3_python_sdk.domain.data_dto import DataEntity
-from is3_python_sdk.utils.config_util import get_header
-from is3_python_sdk.utils.config_util import get_server_name
 
 
-def create_data_entity(filePath, jsonData):
-    serverName = get_server_name(filePath, 'server')
-    headers = get_header(filePath, 'key')
+def create_data_entity(config, jsonData):
+    serverName = config.get('server', 'plugin-code')
+    xAccessKey = config['key']['X-Access-Key']
+    xSecretKey = config['key']['X-Secret-Key']
+    headers = {
+        'Content-Type': 'application/json',
+        'X-Access-Key': xAccessKey,
+        'X-Secret-Key': xSecretKey
+    }
+    bootstrapServers = config['kafka']['bootstrap-servers']
     dataDto = DataEntity(
         preData=jsonData.get('data', {}),
         pluginDataConfig=jsonData.get('pluginDataConfig', {}),
@@ -20,6 +25,6 @@ def create_data_entity(filePath, jsonData):
         headers=headers,
         prjId=int(json.dumps(jsonData.get('prjId', 1))),
         tenantId=1,
-        bootstrapServers='1',
+        bootstrapServers=bootstrapServers,
     )
     return dataDto
